<?php

namespace Hospital\Department\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Hospital\Department\Interfaces\DepartmentRepositoryInterface;

class DepartmentPublicController extends BaseController
{
    // use DepartmentWorkflow;

    /**
     * Constructor.
     *
     * @param type \Hospital\Department\Interfaces\DepartmentRepositoryInterface $department
     *
     * @return type
     */
    public function __construct(DepartmentRepositoryInterface $department)
    {
        $this->repository = $department;
        parent::__construct();
    }

    /**
     * Show department's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $departments = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$department::$department.names'))
            ->view('$department::public.department.index')
            ->data(compact('$departments'))
            ->output();
    }

    /**
     * Show department's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $departments = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$department::$department.names'))
            ->view('$department::public.department.index')
            ->data(compact('$departments'))
            ->output();
    }

    /**
     * Show department.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $department = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$department->name . trans('$department::$department.name'))
            ->view('$department::public.department.show')
            ->data(compact('$department'))
            ->output();
    }

}
